==> viha-5.15.tar.gz: viha-5.15/paivystys-takt.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "paivystys";
$file = "paivystys-takt.php";

include "common.php";
include "paivystys-ok.php";

echo "
<html>
<head>
 <title>VIHA - Operaation perustiedot</title>
</head>
" . body_bgcolor() . "
<h1>" . ota_paivystys_nimi() . ", perustiedot</h1>
";

taktiset_linkit();

$id = s('paivystys');
$nimi = get_txt('nimi');
$oletus_verkko_id = get_nro_1('oletus_verkko_id');
$johto_ryhma_id = get_nro_1('johto_ryhma_id');
$viesti_ryhma_id = get_nro_1('viesti_ryhma_id');
$tuki_ids = get_multi_nro('tuki_ids');

$save = get_txt('save');

# oltava_ ... (thn meill on aina oikeus jos common.php menee lpi)

if (($save != '') && saa_tehda("$file:save")) {
  $ret = paivystys_save_ok($herja,s('paivystys'),
			   s('alue'),
			   $nimi,$oletus_verkko_id,
			   $johto_ryhma_id,$viesti_ryhma_id,$tuki_ids,
			   false);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "UPDATE $table
       SET nimi='$nimi',
           oletus_verkko_id=$oletus_verkko_id,
           johto_ryhma_id = $johto_ryhma_id,
           viesti_ryhma_id = $viesti_ryhma_id,
           ts='$now'
       WHERE id=$id";
    $result = my_mysql_query ($sql,true,true);
    set_tuki_ids($now,$id,$tuki_ids);
    echo "<p>Tiedot pivitetty.\n";
  }
  p_herja($ret,$herja);
 } # save

echo "<form action=\"\" method=\"GET\">\n";

echo "<h2>Operaation perustiedot</h2>\n";

echo "<p><table border=0>\n";

$result = my_mysql_query("SELECT * FROM $table WHERE id = $id");
$a = mysql_fetch_array($result);
$nimi = $a['nimi']; 
$oletus_verkko_id = $a['oletus_verkko_id'];
$johto_ryhma_id = $a['johto_ryhma_id'];
$viesti_ryhma_id = $a['viesti_ryhma_id'];
$tuki_ids = fetch_tuki_ids($id);

echo "<tr><td>Nimi:";
echo "<td><input type=\"text\" name=\"nimi\" size=64 maxlength=255";
echo " value=\"$nimi\">\n";

echo "<tr><td>Oletusradioverkko:";
echo "<td>\n";
tee_valinta("oletus_verkko_id", $oletus_verkko_id, "verkko", "id",
	    "verkko", "ORDER BY verkko");

echo "<tr><td>Operaation johtoryhm:";
echo "<td>\n";
select_johto_ryhma($johto_ryhma_id,$id);

echo "<tr><td>Operaation viestiasema:";
echo "<td>\n";
select_viesti_ryhma($viesti_ryhma_id,$id);

echo "<tr><td>Operaation aputukiasemat:";
echo "<td>\n";
select_tuki_ids($id);

echo "</table>\n";

echo "<input type=\"submit\" name=\"save\" value=\"TALLENNA\">\n";

echo "</form>\n";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: paivystys-takt.php,v 1.5 2009/05/04 05:17:31 riku Exp $ -->

==> viha-5.27.tar.gz: viha-5.27/paivystys-takt.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "paivystys";
$file = "paivystys-takt.php";

include "common.php";
include "paivystys-ok.php";

echo "
<html>
<head>
 <title>VIHA - Operaation perustiedot</title>
</head>
" . body_bgcolor() . "
<h1>" . muotoile_operaatio() . ", perustiedot</h1>
";

taktiset_linkit();

$id = s('paivystys');
$nimi = get_txt('nimi');
$oletus_verkko_id = get_nro_1('oletus_verkko_id');
$johto_ryhma_id = get_nro_1('johto_ryhma_id');
$viesti_ryhma_id = get_nro_1('viesti_ryhma_id');
$tuki_ids = get_multi_nro('tuki_ids');
$alkoi = get_txt('alkoi');
$alkoi = maaginen_kello($alkoi);

$save = get_txt('save');

# oltava_ ... (thn meill on aina oikeus jos common.php menee lpi)

if (($save != '') && saa_tehda("$file:save")) {
  $ret = paivystys_save_ok($herja,s('paivystys'),s('alue'),
			   $nimi,$oletus_verkko_id,
			   $johto_ryhma_id,$viesti_ryhma_id,$tuki_ids,$alkoi,
			   false);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "UPDATE $table
       SET nimi='$nimi',
           oletus_verkko_id=$oletus_verkko_id,
           johto_ryhma_id = $johto_ryhma_id,
           viesti_ryhma_id = $viesti_ryhma_id,
           alkoi='$alkoi',
           ts='$now'
       WHERE id=$id";
    $result = my_mysql_query ($sql,true,true);
    set_tuki_ids($now,$id,$tuki_ids);
    $msg = "Operaation " . muotoile_operaatio($id) . " tietoja pivitetty";
    taktinen_loki($msg);
    tehty($msg);
  }
  p_herja($ret,$herja);
 } # save

echo "<form action=\"\" method=\"GET\">\n";

echo "<h2>Operaation perustiedot</h2>\n";

echo "<p><table border=0>\n";

$result = my_mysql_query("SELECT * FROM $table WHERE id = $id");
$a = mysql_fetch_array($result);
$nimi = $a['nimi']; 
$oletus_verkko_id = $a['oletus_verkko_id'];
$johto_ryhma_id = $a['johto_ryhma_id'];
$viesti_ryhma_id = $a['viesti_ryhma_id'];
$tuki_ids = fetch_tuki_ids($id);
$alkoi = $a['alkoi']; 

echo "<tr><td>Nimi:";
echo "<td><input type=\"text\" name=\"nimi\" size=64 maxlength=255";
echo " value=\"$nimi\">\n";

echo "<tr><td>Oletusradioverkko:";
echo "<td>\n";
tee_valinta("oletus_verkko_id", $oletus_verkko_id, "verkko", "id",
	    "verkko", "ORDER BY verkko");

echo "<tr><td>Operaation johtoryhm:";
echo "<td>\n";
select_johto_ryhma($johto_ryhma_id,$id);

echo "<tr><td>Operaation viestiasema:";
echo "<td>\n";
select_viesti_ryhma($viesti_ryhma_id,$id);

echo "<tr><td>Operaation aputukiasemat:";
echo "<td>\n";
select_tuki_ids($id);

echo "<tr><td>Operaatio alkoi:<td>";
if ($readonly) { echo "$alkoi\n"; } else {
  echo "<input type=\"text\" name=\"alkoi\" size=19 maxlength=19";
  echo " value=\"$alkoi\">
Koska operaatio on aloitettu. HH:MM tai X tai -MM tai +MM.\n";
}

echo "</table>\n";

echo "<input type=\"submit\" name=\"save\" value=\"TALLENNA\">\n";

echo "</form>\n";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: paivystys-takt.php,v 1.7 2009/10/05 16:07:10 riku Exp $ -->
